LocalSessionRepository class

A repository for handling local session state such as memory, storage, etc.

Constructors

LocalSessionRepository()
factory

Properties

activeSession → AuthUserSession?
no setter
hashCode int
The hash code for this object.
no setterinherited
logger → LoggerService
no setter
onSessionChanged Stream<AuthUserSession?>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteAllSessions() Future<void>
Deletes ALL sessions using the Index as source of truth
deleteSession(String userId) Future<void>
Deletes session from Memory, Disk, and Index.
getAllSessionsUserIds() Future<List<String>?>
Tries to find a session in memory first, then disk. If found on disk, it automatically adds it to memory and updates the index.
getSession(String userId) Future<AuthUserSession?>
Tries to find a session in memory first, then disk. If found on disk, it automatically adds it to memory and updates the index.
initialize() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveSession(AuthUserSession session) Future<void>
Saves session to Memory, Disk, and Index.
setActiveSession(AuthUserSession? session) Future<void>
Sets the currently active session and persists the ID.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance LocalSessionRepository
final