getAllSessionsUserIds method

Future<List<String>?> getAllSessionsUserIds()

Tries to find a session in memory first, then disk. If found on disk, it automatically adds it to memory and updates the index.

Implementation

Future<List<String>?> getAllSessionsUserIds() async {
  return _getKnownUserIds();
}