DeactivateSessionsRequest class

Annotations
  • @JsonSerializable.new()

Constructors

DeactivateSessionsRequest({required List<String> userIds, String? mid, required String businessId})
DeactivateSessionsRequest.fromJson(Map<String, dynamic> json)
factory

Properties

businessId String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
mid String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userIds List<String>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited