AuthUsersService class

Constructors

AuthUsersService({required String baseUrl, required String businessId, bool useBaseSession = false, @visibleForTesting LittleFishHttpClient? httpClient})

Properties

baseUrl String
getter/setter pair
businessId String
getter/setter pair
client → LittleFishHttpClient
no setter
core ↔ LittleFishCore
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
logger → LoggerService
no setter
monitoringService → MonitoringService<dynamic, MonitoringHttpMetric, MonitoringTrace>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useBaseSession bool
When true, API calls use the base (admin) user's session token instead of the switched user's token.
final

Methods

getBusinessRoles({required String businessId}) Future<List<AuthBusinessRoleDto>>
getBusinessUsersByBusinessId() Future<List<BusinessUser>>
getUserRoles({required String businessId}) Future<List<AuthUserRoleDto>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited