DeviceHelper class

A helper class to retrieve device information

Ideally device information should be coming from terminal manager, but currently it is coupled with littlefish payments however, littlefish auth should not depend on payments.

Constructors

DeviceHelper()

Properties

core ↔ LittleFishCore
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
logger → LoggerService
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDeviceId() Future<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited