AuthSessionService class
- Inheritance
-
- Object
- LittleFishService
- AuthSessionService
Constructors
- AuthSessionService()
-
factory
Properties
Methods
-
createSession(
CreateSessionRequest request) → Future< AuthUserSessionDto> -
deleteAllSessions(
DeactivateSessionsRequest request) → Future< void> -
deleteSession(
DeleteSessionRequest request) → Future< void> -
getSession(
String userId, {String? mid, String? businessId}) → Future< AuthUserSessionDto?> -
initialise(
) → Future< void> - Initializes the service with necessary configuration. Must be called once before any other methods are used.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
refreshSession(
UpdateSessionRequest request) → Future< AuthUserSessionDto> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → AuthSessionService
-
final