DeviceHelper class
A helper class to retrieve device information
Ideally device information should be coming from terminal manager, but currently it is coupled with littlefish payments however, littlefish auth should not depend on payments.
Constructors
Properties
Methods
-
getDeviceId(
) → Future< String> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited